"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.printNxCloudSuccessMessage = exports.setupNxCloud = void 0;
const tslib_1 = require("tslib");
const ora = require("ora");
const path_1 = require("path");
const child_process_utils_1 = require("../child-process-utils");
const output_1 = require("../output");
const package_manager_1 = require("../package-manager");
const string_utils_1 = require("../string-utils");
function setupNxCloud(name, packageManager) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const nxCloudSpinner = ora(`Setting up NxCloud`).start();
        try {
            const pmc = (0, package_manager_1.getPackageManagerCommand)(packageManager);
            const res = yield (0, child_process_utils_1.execAndWait)(`${pmc.exec} nx g @nrwl/nx-cloud:init --no-analytics --installationSource=create-nx-workspace`, (0, path_1.join)(process.cwd(), (0, string_utils_1.getFileName)(name)));
            nxCloudSpinner.succeed('NxCloud has been set up successfully');
            return res;
        }
        catch (e) {
            nxCloudSpinner.fail();
            output_1.output.error({
                title: `Nx failed to setup NxCloud`,
                bodyLines: (0, string_utils_1.mapErrorToBodyLines)(e),
            });
            process.exit(1);
        }
        finally {
            nxCloudSpinner.stop();
        }
    });
}
exports.setupNxCloud = setupNxCloud;
function printNxCloudSuccessMessage(nxCloudOut) {
    const bodyLines = nxCloudOut
        .split('Distributed caching via Nx Cloud has been enabled')[1]
        .trim();
    output_1.output.note({
        title: `Distributed caching via Nx Cloud has been enabled`,
        bodyLines: bodyLines.split('\n').map((r) => r.trim()),
    });
}
exports.printNxCloudSuccessMessage = printNxCloudSuccessMessage;
//# sourceMappingURL=nx-cloud.js.map